@@ -4,7 +4,7 @@ from django.conf import settings
 from django.core.cache import cache
 from django.http import Http404, HttpRequest
 from django.shortcuts import render
-from django.utils.html import mark_safe
+from django.utils.html import mark_safe  # type: ignore
 
 from .renderer import render_markdown
 
@@ -12,6 +12,20 @@ from .renderer import render_markdown
 logger = logging.getLogger(__name__)
 
 
+DEFAULT_VIEW_CACHE_SECONDS = 60 * 60
+
+
+def _get_view_cache_seconds() -> int:
+    """
+    Get the view cache seconds from settings or just send back the default of an hour.
+    """
+
+    if hasattr(settings, "COLTRANE") and isinstance(settings.COLTRANE, dict):
+        return settings.COLTRANE.get("VIEW_CACHE_SECONDS", DEFAULT_VIEW_CACHE_SECONDS)
+
+    return DEFAULT_VIEW_CACHE_SECONDS
+
+
 def content(request: HttpRequest, slug: str = "index"):
     """
     Renders the markdown file stored in `content` based on the slug from the URL. Adds data into the context
@@ -40,7 +54,7 @@ def content(request: HttpRequest, slug: str = "index"):
                 cache.set(
                     cache_key,
                     (content, data),
-                    settings.COLTRAN.get("VIEW_CACHE_SECONDS", 60 * 60),
+                    _get_view_cache_seconds(),
                 )
     except FileNotFoundError:
         raise Http404(f"{slug} cannot be found")
